(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "@emotion/core", "react", "react-head", "./components/Codeblog", "./components/CodeblogContext", "./template", "./components/SEOTags"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("@emotion/core"), require("react"), require("react-head"), require("./components/Codeblog"), require("./components/CodeblogContext"), require("./template"), require("./components/SEOTags"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.core, global.react, global.reactHead, global.Codeblog, global.CodeblogContext, global.template, global.SEOTags);
    global.index = mod.exports;
  }
})(this, function (_exports, _core, React, _reactHead, _Codeblog, _CodeblogContext, Template, _SEOTags) {
  "use strict";

  Object.defineProperty(_exports, "__esModule", {
    value: true
  });
  Object.defineProperty(_exports, "CodeblogProvider", {
    enumerable: true,
    get: function get() {
      return _Codeblog.CodeblogProvider;
    }
  });
  Object.defineProperty(_exports, "BlogComponentType", {
    enumerable: true,
    get: function get() {
      return _CodeblogContext.BlogComponentType;
    }
  });
  Object.defineProperty(_exports, "BlogPostComponentType", {
    enumerable: true,
    get: function get() {
      return _CodeblogContext.BlogPostComponentType;
    }
  });
  Object.defineProperty(_exports, "CodeblogContext", {
    enumerable: true,
    get: function get() {
      return _CodeblogContext.CodeblogContext;
    }
  });
  Object.defineProperty(_exports, "CodeblogContextInterface", {
    enumerable: true,
    get: function get() {
      return _CodeblogContext.CodeblogContextInterface;
    }
  });
  Object.defineProperty(_exports, "Post", {
    enumerable: true,
    get: function get() {
      return _CodeblogContext.Post;
    }
  });
  Object.defineProperty(_exports, "Blog", {
    enumerable: true,
    get: function get() {
      return _CodeblogContext.Blog;
    }
  });
  Object.defineProperty(_exports, "EnvironmentType", {
    enumerable: true,
    get: function get() {
      return _CodeblogContext.EnvironmentType;
    }
  });
  Object.defineProperty(_exports, "PageType", {
    enumerable: true,
    get: function get() {
      return _CodeblogContext.PageType;
    }
  });
  Object.defineProperty(_exports, "BlogSEOTags", {
    enumerable: true,
    get: function get() {
      return _SEOTags.BlogSEOTags;
    }
  });
  Object.defineProperty(_exports, "BlogPostSEOTags", {
    enumerable: true,
    get: function get() {
      return _SEOTags.BlogPostSEOTags;
    }
  });
  Object.defineProperty(_exports, "Title", {
    enumerable: true,
    get: function get() {
      return _SEOTags.Title;
    }
  });
  Object.defineProperty(_exports, "Meta", {
    enumerable: true,
    get: function get() {
      return _SEOTags.Meta;
    }
  });
  Object.defineProperty(_exports, "Link", {
    enumerable: true,
    get: function get() {
      return _SEOTags.Link;
    }
  });
  _exports.Template = _exports["default"] = _exports.Codeblog = _exports.CodeblogPostEditor = _exports.CodeblogIndexPage = _exports.CodeblogPost = _exports.CodeblogRoot = void 0;
  React = _interopRequireWildcard(React);
  Template = _interopRequireWildcard(Template);
  _exports.Template = Template;

  function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

  function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

  function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

  function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

  var CodeblogRoot = function CodeblogRoot(props) {
    if (props.pageType === "show") {
      return (0, _core.jsx)(CodeblogPost, props);
    } else if (props.pageType === "editor") {
      return (0, _core.jsx)(CodeblogPostEditor, props);
    } else if (props.pageType === "index") {
      return (0, _core.jsx)(CodeblogIndexPage, props);
    } else {
      return null;
    }
  };

  _exports.CodeblogRoot = CodeblogRoot;

  var CodeblogPost = function CodeblogPost(props) {
    var BlogComponent = props.BlogComponent,
        BlogPostComponent = props.BlogPostComponent;
    return (0, _core.jsx)(_reactHead.HeadProvider, {
      headTags: props.headTags
    }, (0, _core.jsx)(_Codeblog.CodeblogProvider, {
      pageType: "show",
      environment: props.environment,
      post: _objectSpread({}, props.post, {
        body: props.children
      }),
      blog: props.blog,
      BlogComponent: BlogComponent,
      BlogPostComponent: BlogPostComponent
    }, (0, _core.jsx)(_CodeblogContext.CodeblogContext.Consumer, null, function (contextProps) {
      return (0, _core.jsx)(BlogComponent, contextProps, props.children);
    })));
  };

  _exports.CodeblogPost = CodeblogPost;

  var CodeblogIndexPage = function CodeblogIndexPage(props) {
    var BlogComponent = props.BlogComponent,
        BlogPostComponent = props.BlogPostComponent;
    return (0, _core.jsx)(_reactHead.HeadProvider, {
      headTags: props.headTags
    }, (0, _core.jsx)(_Codeblog.CodeblogProvider, {
      pageType: "index",
      environment: props.environment,
      posts: props.posts,
      blog: props.blog,
      BlogComponent: BlogComponent,
      BlogPostComponent: BlogPostComponent
    }, (0, _core.jsx)(_CodeblogContext.CodeblogContext.Consumer, null, function (contextProps) {
      return (0, _core.jsx)(BlogComponent, contextProps, React.Children.map(props.children, function (child, index) {
        return (0, _core.jsx)(_Codeblog.CodeblogProvider, {
          pageType: "index",
          environment: props.environment,
          post: contextProps.posts[index],
          posts: [],
          blog: props.blog,
          BlogComponent: BlogComponent,
          BlogPostComponent: BlogPostComponent
        }, (0, _core.jsx)(BlogPostComponent, _extends({}, contextProps, {
          post: contextProps.posts[index]
        }), child));
      }));
    })));
  };

  _exports.CodeblogIndexPage = CodeblogIndexPage;

  var CodeblogPostEditor = function CodeblogPostEditor(props) {
    var BlogComponent = props.BlogComponent,
        BlogPostComponent = props.BlogPostComponent;
    return (0, _core.jsx)(_reactHead.HeadProvider, {
      headTags: props.headTags
    }, (0, _core.jsx)(_Codeblog.CodeblogProvider, {
      pageType: "editor",
      environment: props.environment,
      post: _objectSpread({}, props.post, {
        body: props.children
      }),
      blog: props.blog,
      BlogComponent: BlogComponent,
      BlogPostComponent: BlogPostComponent
    }, (0, _core.jsx)(_CodeblogContext.CodeblogContext.Consumer, null, function (contextProps) {
      return (0, _core.jsx)(BlogComponent, contextProps, props.children);
    })));
  };

  _exports.CodeblogPostEditor = CodeblogPostEditor;
  var Codeblog = _CodeblogContext.CodeblogContext.Consumer;
  _exports.Codeblog = Codeblog;
  var _default = Codeblog;
  _exports["default"] = _default;
});