import * as React from "react";
import { ComponentManifest, CategoryType } from "../registry";
declare type ImageURLShape = {
    ["1x"]: string;
    ["2x"]: string;
    ["3x"]: string;
};
export declare type ComponentManifestMap = {
    [key: string]: ComponentManifest;
};
declare type SchemaValue = {
    isVoid?: boolean;
};
declare type MiniSlateSchema = {
    blocks: {
        [id: string]: SchemaValue;
    };
    inlines: {
        [id: string]: SchemaValue;
    };
};
declare type OnChangeFunction = (components: ComponentManifestMap) => void;
export declare type RegistryContextType = {
    Inlines: ComponentManifestMap;
    Blocks: ComponentManifestMap;
    schema: MiniSlateSchema;
    onChangeBlocks: OnChangeFunction;
    onChangeInlines: OnChangeFunction;
    onChangeDevelopmentComponents: (blocks: ComponentManifestMap, inlines: ComponentManifestMap) => void;
    onChange: (blocks: ComponentManifestMap, inlines: ComponentManifestMap) => void;
};
export declare const RegistryContext: React.Context<RegistryContextType>;
declare type Props = {
    initialInlines: ComponentManifestMap;
    initialBlocks: ComponentManifestMap;
    children: React.ReactChildren;
};
declare type StateWithoutContext = {
    blocks: ComponentManifestMap;
    inlines: ComponentManifestMap;
    schema: MiniSlateSchema;
};
declare type State = StateWithoutContext & {
    contextValue: RegistryContextType;
};
export declare const isVoid: (manifest: ComponentManifest) => boolean;
export declare function normalizeBlock({ title, description, screenshot, category, placeholder, src, isRemote, isVoid, Component, isDevelopment, EditorComponent: _EditorComponent, editableProps, defaultProps, id }: ComponentManifest): {
    title: string;
    description: string;
    category: CategoryType;
    src: string;
    screenshot: ImageURLShape;
    isRemote: boolean;
    isDevelopment: boolean;
    isVoid: boolean;
    placeholder: string;
    Component: React.ComponentType<any>;
    EditorComponent: React.ComponentType<any>;
    editableProps: import("./EditableProps").EditablePropMap;
    defaultProps: {
        [x: string]: string;
    };
    id: string;
};
export declare function normalizeInline({ title, description, screenshot, placeholder, category, src, isRemote, isDevelopment, Component, EditorComponent: _EditorComponent, editableProps, defaultProps, id }: ComponentManifest): {
    title: string;
    description: string;
    screenshot: ImageURLShape;
    isDevelopment: boolean;
    placeholder: string;
    Component: React.ComponentType<any>;
    src: string;
    isRemote: boolean;
    EditorComponent: React.ComponentType<any>;
    category: CategoryType;
    id: string;
    editableProps: import("./EditableProps").EditablePropMap;
    defaultProps: {
        [x: string]: string;
    };
};
export declare class RegistryProvider extends React.PureComponent<Props, State> {
    constructor(props: Props);
    handleChangeBlocks: (blocks: ComponentManifestMap) => void;
    handleChangeDevelopmentComponents: (blocks: ComponentManifestMap, inlines: ComponentManifestMap) => void;
    handleChange: (blocks: ComponentManifestMap, inlines: ComponentManifestMap) => void;
    handleChangeInlines: (inlines: ComponentManifestMap) => void;
    render(): JSX.Element;
}
export {};
